==> evolution-2.29.2.tar.gz: evolution-2.29.2/widgets/misc/e-image-chooser.h <==
/*
 * e-image-chooser.h
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) version 3.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with the program; if not, see <http://www.gnu.org/licenses/>
 *
 *
 * Copyright (C) 1999-2008 Novell, Inc. (www.novell.com)
 *
 */

#ifndef E_IMAGE_CHOOSER_H
#define E_IMAGE_CHOOSER_H

#include <gtk/gtk.h>

/* Standard GObject macros */
#define E_TYPE_IMAGE_CHOOSER \
	(e_image_chooser_get_type ())
#define E_IMAGE_CHOOSER(obj) \
	(G_TYPE_CHECK_INSTANCE_CAST \
	((obj), E_TYPE_IMAGE_CHOOSER, EImageChooser))
#define E_IMAGE_CHOOSER_CLASS(cls) \
	(G_TYPE_CHECK_CLASS_CAST \
	((cls), E_TYPE_IMAGE_CHOOSER, EImageChooserClass))
#define E_IS_IMAGE_CHOOSER(obj) \
	(G_TYPE_CHECK_INSTANCE_TYPE \
	((obj), E_TYPE_IMAGE_CHOOSER))
#define E_IS_IMAGE_CHOOSER_CLASS(cls) \
	(G_TYPE_CHECK_CLASS_TYPE \
	((cls), E_TYPE_IMAGE_CHOOSER))
#define E_IMAGE_CHOOSER_GET_CLASS(obj) \
	(G_TYPE_INSTANCE_GET_CLASS \
	((obj), E_TYPE_IMAGE_CHOOSER, EImageChooserClass))

G_BEGIN_DECLS

typedef struct _EImageChooser EImageChooser;
typedef struct _EImageChooserClass EImageChooserClass;
typedef struct _EImageChooserPrivate EImageChooserPrivate;

struct _EImageChooser {
	GtkVBox parent;
	EImageChooserPrivate *priv;
};

struct _EImageChooserClass {
	GtkVBoxClass parent_class;

	/* signals */
	void (*changed) (EImageChooser *chooser);
};

GType		e_image_chooser_get_type	(void);
GtkWidget *	e_image_chooser_new		(void);
gboolean	e_image_chooser_set_from_file	(EImageChooser *chooser,
						 const gchar *filename);
gboolean	e_image_chooser_set_image_data	(EImageChooser *chooser,
						 gchar *data,
						 gsize data_length);
gboolean	e_image_chooser_get_image_data	(EImageChooser *chooser,
						 gchar **data,
						 gsize *data_length);

#endif /* E_IMAGE_CHOOSER_H */

==> evolution-2.31.90.tar.gz: evolution-2.31.90/widgets/misc/e-image-chooser.h <==
/*
 * e-image-chooser.h
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) version 3.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with the program; if not, see <http://www.gnu.org/licenses/>
 *
 *
 * Copyright (C) 1999-2008 Novell, Inc. (www.novell.com)
 *
 */

#ifndef E_IMAGE_CHOOSER_H
#define E_IMAGE_CHOOSER_H

#include <gtk/gtk.h>

/* Standard GObject macros */
#define E_TYPE_IMAGE_CHOOSER \
	(e_image_chooser_get_type ())
#define E_IMAGE_CHOOSER(obj) \
	(G_TYPE_CHECK_INSTANCE_CAST \
	((obj), E_TYPE_IMAGE_CHOOSER, EImageChooser))
#define E_IMAGE_CHOOSER_CLASS(cls) \
	(G_TYPE_CHECK_CLASS_CAST \
	((cls), E_TYPE_IMAGE_CHOOSER, EImageChooserClass))
#define E_IS_IMAGE_CHOOSER(obj) \
	(G_TYPE_CHECK_INSTANCE_TYPE \
	((obj), E_TYPE_IMAGE_CHOOSER))
#define E_IS_IMAGE_CHOOSER_CLASS(cls) \
	(G_TYPE_CHECK_CLASS_TYPE \
	((cls), E_TYPE_IMAGE_CHOOSER))
#define E_IMAGE_CHOOSER_GET_CLASS(obj) \
	(G_TYPE_INSTANCE_GET_CLASS \
	((obj), E_TYPE_IMAGE_CHOOSER, EImageChooserClass))

G_BEGIN_DECLS

typedef struct _EImageChooser EImageChooser;
typedef struct _EImageChooserClass EImageChooserClass;
typedef struct _EImageChooserPrivate EImageChooserPrivate;

struct _EImageChooser {
	GtkVBox parent;
	EImageChooserPrivate *priv;
};

struct _EImageChooserClass {
	GtkVBoxClass parent_class;

	/* signals */
	void (*changed) (EImageChooser *chooser);
};

GType		e_image_chooser_get_type	(void);
GtkWidget *	e_image_chooser_new		(const gchar *icon_name);
const gchar *	e_image_chooser_get_icon_name	(EImageChooser *chooser);
gboolean	e_image_chooser_set_from_file	(EImageChooser *chooser,
						 const gchar *filename);
gboolean	e_image_chooser_set_image_data	(EImageChooser *chooser,
						 gchar *data,
						 gsize data_length);
gboolean	e_image_chooser_get_image_data	(EImageChooser *chooser,
						 gchar **data,
						 gsize *data_length);

#endif /* E_IMAGE_CHOOSER_H */
